@@ -11,6 +11,8 @@ import { closeDatabase, initDatabase, initReporting } from './database';
 import { initIntegrations } from './integrations';
 import { defineSingletonTelegramBotService } from './services/TelegramBotService';
 import { VERSION } from './middleware/versionCompatibility';
+import { initDeviceId } from '@tamanu/shared/utils';
+import { DEVICE_TYPES } from '@tamanu/constants';
 
 export const CENTRAL_SERVER_APP_TYPES = {
   API: 'api',
@@ -43,6 +45,9 @@ export class ApplicationContext {
   /**@type {ReadSettings<CentralSettingPath> | null} */
   settings = null;
 
+  /** @type {string | null} */
+  deviceId = null;
+
   closeHooks = [];
 
   async init({ testMode, appType = CENTRAL_SERVER_APP_TYPES.MAIN, dbKey } = {}) {
@@ -58,7 +63,7 @@ export class ApplicationContext {
 
     this.store = await initDatabase({ testMode, dbKey: dbKey ?? appType });
 
-    this.closePromise = new Promise((resolve) => {
+    this.closePromise = new Promise(resolve => {
       this.onClose(resolve);
     });
 
@@ -69,6 +74,8 @@ export class ApplicationContext {
       return this;
     }
 
+    await initDeviceId({ context: this, deviceType: DEVICE_TYPES.CENTRAL_SERVER });
+
     this.emailService = new EmailService();
 
     if (config.db.reportSchemas?.enabled) {
@@ -86,16 +93,16 @@ export class ApplicationContext {
     }
 
     this.timesync = new Timesimp(
-      async (err) => {
+      async err => {
         if (err) throw err;
         // we assume central-server time is correct
         return 0;
       },
-      async (err) => {
+      async err => {
         if (err) throw err;
         // we assume central-server time is correct
       },
-      async (err) => {
+      async err => {
         if (err) throw err;
         throw new Error('No upstream timesync server for central');
       },
