@@ -17,6 +17,8 @@ import { reportsRouter } from './reports/reportRoutes';
 import { syncLastCompleted } from './sync';
 import { translationRouter } from './translation';
 import { usersRouter } from './users';
+import { userPreferencesRouter } from './userPreferences';
+import { locationAssignmentsRouter } from './locationAssignments';
 
 export const adminRoutes = express.Router();
 adminRoutes.use(ensurePermissionCheck);
@@ -68,6 +70,8 @@ adminRoutes.use('/template', templateRoutes);
 
 adminRoutes.use('/asset', assetRoutes);
 adminRoutes.use('/users', usersRouter);
+adminRoutes.use('/user', userPreferencesRouter);
+adminRoutes.use('/location-assignments', locationAssignmentsRouter);
 
 // These settings endpoints are setup for viewing and saving the settings in the JSON editor in the admin panel
 adminRoutes.get(
