@@ -3,7 +3,7 @@ import { Op, QueryTypes } from 'sequelize';
 import _config from 'config';
 import { isNil } from 'lodash';
 
-import { DEBUG_LOG_TYPES, SETTINGS_SCOPES } from '@tamanu/constants';
+import { DEBUG_LOG_TYPES, SETTINGS_SCOPES, SYNC_DIRECTIONS } from '@tamanu/constants';
 import { FACT_CURRENT_SYNC_TICK, FACT_LOOKUP_UP_TO_TICK } from '@tamanu/constants/facts';
 import { log } from '@tamanu/shared/services/logging';
 import {
@@ -723,9 +723,63 @@ export class CentralSyncManager {
     }
   }
 
+  #modelMap = null;
   async addIncomingChanges(sessionId, changes) {
-    const { sequelize } = this.store;
+    const { sequelize, models } = this.store;
     await this.connectToSession(sessionId);
+
+    if (!this.#modelMap) {
+      this.#modelMap = new Map(
+        Object.values(models)
+          .filter(m => m.tableName && m.usesPublicSchema)
+          .map(m => [m.tableName, m])
+      );
+    }
+
+    for (const change of changes) {
+      const model = this.#modelMap.get(change.recordType);
+      if (!model) {
+        const errorMessage = `Sync security violation: Attempted to push record with unknown model`;
+        log.error(errorMessage, {
+          recordType: change.recordType,
+          recordId: change.recordId,
+          reason: 'Model not found',
+          sessionId,
+        });
+
+        await models.SyncSession.addDebugInfo(sessionId, {
+          rejectedRecord: { type: change.recordType, id: change.recordId },
+        });
+
+        await models.SyncSession.markSessionErrored(sessionId, errorMessage);
+        throw new Error(errorMessage);
+      }
+
+      if (
+        ![
+          SYNC_DIRECTIONS.PUSH_TO_CENTRAL,
+          SYNC_DIRECTIONS.PUSH_TO_CENTRAL_THEN_DELETE,
+          SYNC_DIRECTIONS.BIDIRECTIONAL,
+        ].includes(model.syncDirection)
+      ) {
+        const errorMessage = `Sync security violation: Attempted to push record that is not allowed to be pushed`;
+        log.error(errorMessage, {
+          recordType: change.recordType,
+          recordId: change.recordId,
+          syncDirection: model.syncDirection,
+          reason: `Model has syncDirection '${model.syncDirection}' which is not allowed for push operations`,
+          sessionId,
+        });
+
+        await models.SyncSession.addDebugInfo(sessionId, {
+          rejectedRecord: { type: change.recordType, id: change.recordId },
+        });
+
+        await models.SyncSession.markSessionErrored(sessionId, errorMessage);
+        throw new Error(errorMessage);
+      }
+    }
+
     const incomingSnapshotRecords = changes.map(c => ({
       ...c,
       direction: SYNC_SESSION_DIRECTION.INCOMING,
