@@ -2,6 +2,7 @@ import { Sequelize } from 'sequelize';
 import type { SYNC_DIRECTIONS } from '@tamanu/constants';
 import type { Models } from './model';
 import type { SYNC_SESSION_DIRECTION } from '../sync/constants';
+import type { ChangeLog } from 'models/ChangeLog';
 
 export interface SessionConfig {
   syncAllLabRequests: boolean;
@@ -38,6 +39,10 @@ export interface SyncSnapshotAttributes {
   requiresRepull?: boolean;
 }
 
+export interface SyncSnapshotAttributesWithChangelog extends SyncSnapshotAttributes {
+  changelogRecords?: ChangeLog[];
+}
+
 export type UninsertedSyncSnapshotAttributes = Omit<
   SyncSnapshotAttributes,
   'id' | 'savedAtSyncTick'
