@@ -149,11 +149,6 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: false,
         },
-        enableInvoicing: {
-          description: 'Enable invoice tab/module on encounter view',
-          type: yup.boolean(),
-          defaultValue: false,
-        },
         enableTasking: {
           description: 'Enable tasking tab/module on encounter view',
           type: yup.boolean(),
@@ -335,7 +330,7 @@ export const globalSettings = {
             enabled: {
               description: 'Enable pharmacy orders',
               type: yup.boolean(),
-              defaultValue: false,
+              defaultValue: true,
             },
             medicationAlreadyOrderedConfirmationTimeout: {
               description:
@@ -344,6 +339,11 @@ export const globalSettings = {
               defaultValue: 24,
               unit: 'hours',
             },
+            sendViaMSupply: {
+              description: 'Send pharmacy orders to mSupply (when an integration is configured)',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
           },
         },
         useGlobalPdfFont: {
@@ -361,6 +361,33 @@ export const globalSettings = {
             },
           },
         },
+        invoicing: {
+          description: 'Invoicing module settings',
+          properties: {
+            enabled: {
+              description: 'Enable invoicing',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+            invoicePendingLabRequests: {
+              description:
+                'This setting enables automatically adding lab requests with the status Sample not collected & Reception pending to an invoice.',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+            invoicePendingImagingRequests: {
+              description:
+                'This setting enables automatically adding imaging requests with the status pending to an invoice.',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+            slidingFeeScale: {
+              description: 'This setting allows sliding fee scale to be applied to invoices.',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+          },
+        },
         labRequest: {
           description: 'Lab request settings',
           properties: {
@@ -1221,6 +1248,13 @@ export const globalSettings = {
                 schedulingLocations: { properties: layoutModuleProperties },
               },
             },
+            medication: {
+              description: '_',
+              properties: {
+                medicationActive: { properties: layoutModuleProperties },
+                medicationDispensed: { properties: layoutModuleProperties },
+              },
+            },
             imaging: {
               description: '_',
               properties: {
@@ -1560,9 +1594,49 @@ export const globalSettings = {
         },
       },
     },
+    patientPortal: {
+      description: 'Patient portal settings',
+      properties: {
+        baseUrl: {
+          description: 'The base URL of the patient portal',
+          type: yup.string().trim().url().nullable(),
+          defaultValue: null,
+        },
+      },
+    },
     medications: {
       description: 'Medication settings',
       properties: {
+        dispensing: {
+          description: 'Medication dispensing settings',
+          properties: {
+            prescriptionLabelSize: {
+              description: 'Prescription label size.',
+              properties: {
+                width: {
+                  description: 'Prescription label width.',
+                  type: yup.number().min(1),
+                  defaultValue: 80,
+                  unit: 'mm',
+                },
+                height: {
+                  description: 'Prescription label height.',
+                  type: yup.number().min(1),
+                  defaultValue: 40,
+                  unit: 'mm',
+                },
+              },
+            },
+            autoDeleteTimeframeHours: {
+              name: 'Autodelete medication request timeframe in hours',
+              description:
+                'Medication requests not dispensed after this timeframe will be automatically deleted.',
+              type: yup.number().integer().positive(),
+              defaultValue: 72,
+              unit: 'hours',
+            },
+          },
+        },
         frequenciesEnabled: {
           description: 'Enable medication frequencies',
           properties: {
