@@ -1,6 +1,5 @@
-import { Document, StyleSheet, View } from '@react-pdf/renderer';
+import { Document, StyleSheet, Text, View } from '@react-pdf/renderer';
 import React from 'react';
-
 import { DRUG_ROUTE_LABELS } from '@tamanu/constants';
 
 import { CertificateContent, CertificateHeader, Col, Signature, styles } from './Layout';
@@ -9,52 +8,74 @@ import { Table } from './Table';
 import { DataSection } from './printComponents/DataSection';
 import { DataItem } from './printComponents/DataItem';
 import { getDisplayDate } from './getDisplayDate';
-import { getCurrentDateString } from '../dateTime';
+import { getCurrentDateString } from '@tamanu/utils/dateTime';
 import { LetterheadSection } from './LetterheadSection';
-import { P } from './Typography';
-import { withLanguageContext } from '../pdf/languageContext';
+import { useLanguageContext, withLanguageContext } from '../pdf/languageContext';
 import { Page } from '../pdf/Page';
+import { getMedicationDoseDisplay, getTranslatedFrequency } from '../medication';
+import { Footer } from './printComponents/Footer';
 
-const columns = [
+const columns = (getTranslation, getEnumTranslation) => [
   {
     key: 'medication',
-    title: 'Medication',
-    accessor: ({ medication }) => (medication || {}).name,
-    customStyles: { minWidth: 100 },
+    title: getTranslation('pdf.table.column.medication', 'Medication'),
+    accessor: ({ medication, notes, indication }) => (
+      <View>
+        <Text>{medication?.name + `\n`}</Text>
+        {notes && <Text style={{ fontFamily: 'Helvetica-Oblique' }}>{notes + `\n`}</Text>}
+        {indication && (
+          <Text>
+            <Text style={{ fontFamily: 'Helvetica-Bold' }}>
+              {getTranslation('medication.indication.label', 'Indication')}:
+            </Text>
+            <Text>{` ${indication}`}</Text>
+          </Text>
+        )}
+      </View>
+    ),
+    customStyles: { minWidth: 180 },
   },
   {
-    key: 'prescription',
-    title: 'Instructions',
-    customStyles: { minWidth: 100 },
+    key: 'dose',
+    title: getTranslation('pdf.table.column.dose', 'Dose'),
+    accessor: (medication) => {
+      return (
+        <Text>
+          {getMedicationDoseDisplay(medication, getTranslation, getEnumTranslation)}
+          {medication?.isPrn && ` ${getTranslation('medication.table.prn', 'PRN')}`}
+        </Text>
+      );
+    },
+  },
+  {
+    key: 'frequency',
+    title: getTranslation('pdf.table.column.frequency', 'Frequency'),
+    accessor: ({ frequency }) => getTranslatedFrequency(frequency, getTranslation),
+    customStyles: { minWidth: 30 },
   },
   {
     key: 'route',
-    title: 'Route',
-    accessor: ({ route }) => DRUG_ROUTE_LABELS[route] || '',
+    title: getTranslation('pdf.table.column.route', 'Route'),
+    accessor: ({ route }) => getEnumTranslation(DRUG_ROUTE_LABELS, route),
   },
   {
     key: 'quantity',
-    title: 'Quantity',
+    title: getTranslation('pdf.table.column.quantity', 'Quantity'),
+    accessor: ({ quantity }) => quantity,
   },
   {
     key: 'repeats',
-    title: 'Repeats',
+    title: getTranslation('pdf.table.column.repeats', 'Repeats'),
+    accessor: ({ repeats }) => repeats,
   },
 ];
 
-const prescriptonSectionStyles = StyleSheet.create({
+const prescriptionSectionStyles = StyleSheet.create({
   tableContainer: {
     marginTop: 12,
   },
 });
 
-const notesSectionStyles = StyleSheet.create({
-  notesContainer: {
-    border: '1px solid black',
-    height: 69,
-  },
-});
-
 const signingSectionStyles = StyleSheet.create({
   container: {
     marginTop: 22,
@@ -67,7 +88,7 @@ const generalStyles = StyleSheet.create({
   },
 });
 
-const SectionContainer = props => <View style={generalStyles.container} {...props} />;
+const SectionContainer = (props) => <View style={generalStyles.container} {...props} />;
 
 const PrescriptionsSection = ({
   prescriptions,
@@ -76,6 +97,7 @@ const PrescriptionsSection = ({
   getLocalisation,
   getSetting,
 }) => {
+  const { getTranslation, getEnumTranslation } = useLanguageContext();
   return (
     <View>
       <DataSection hideBottomRule title="Prescription details">
@@ -88,12 +110,13 @@ const PrescriptionsSection = ({
           <DataItem label="Facility" value={facility?.name} />
         </Col>
       </DataSection>
-      <View style={prescriptonSectionStyles.tableContainer}>
+      <View style={prescriptionSectionStyles.tableContainer}>
         <Table
-          columns={columns}
+          columns={columns(getTranslation, getEnumTranslation)}
           data={prescriptions}
           getLocalisation={getLocalisation}
           getSetting={getSetting}
+          columnStyle={{ padding: '8px 7px' }}
         />
       </View>
     </View>
@@ -107,15 +130,6 @@ const PrescriptionSigningSection = () => (
   </View>
 );
 
-const NotesSection = () => (
-  <View>
-    <P bold fontSize={11} mb={3}>
-      Notes
-    </P>
-    <View style={notesSectionStyles.notesContainer} />
-  </View>
-);
-
 const PrescriptionPrintoutComponent = ({
   patientData,
   prescriptions,
@@ -127,7 +141,7 @@ const PrescriptionPrintoutComponent = ({
 }) => {
   return (
     <Document>
-      <Page size="A4" style={styles.page}>
+      <Page size="A4" style={[styles.page, { paddingBottom: '50' }]}>
         <CertificateHeader>
           <LetterheadSection
             letterheadConfig={certificateData}
@@ -135,10 +149,10 @@ const PrescriptionPrintoutComponent = ({
             certificateTitle="Prescription"
           />
           <SectionContainer>
-            <PatientDetailsWithBarcode patient={patientData} getLocalisation={getLocalisation} />
+            <PatientDetailsWithBarcode patient={patientData} getLocalisation={getLocalisation} getSetting={getSetting} />
           </SectionContainer>
         </CertificateHeader>
-        <CertificateContent>
+        <CertificateContent style={{ margin: 0 }}>
           <SectionContainer>
             <PrescriptionsSection
               prescriptions={prescriptions}
@@ -148,13 +162,11 @@ const PrescriptionPrintoutComponent = ({
               getSetting={getSetting}
             />
           </SectionContainer>
-          <SectionContainer>
-            <NotesSection />
-          </SectionContainer>
           <SectionContainer>
             <PrescriptionSigningSection />
           </SectionContainer>
         </CertificateContent>
+        <Footer style={{ left: 30, right: 30 }} />
       </Page>
     </Document>
   );
