@@ -15,18 +15,26 @@ export const getSurveyAnswerRows = ({ components, answers }) =>
   components
     .filter(shouldShow)
     .map(component => {
-      const { dataElement, id, screenIndex } = component;
-      const { type, name } = dataElement;
+      const { dataElement, id, screenIndex, config } = component;
+      const { type: originalType, name } = dataElement;
       const answerObject = answers.find(a => a.dataElementId === dataElement.id);
       const answer = answerObject?.body;
       const sourceType = answerObject?.sourceType;
+      const sourceConfig = answerObject?.sourceConfig;
+      const componentConfig =
+        originalType === PROGRAM_DATA_ELEMENT_TYPES.SURVEY_ANSWER ? sourceConfig : config;
+      const type =
+        originalType === PROGRAM_DATA_ELEMENT_TYPES.SURVEY_ANSWER ? sourceType : originalType;
+
       return {
         id,
         type,
         answer,
         name,
         screenIndex,
-        sourceType,
+        dataElementId: dataElement.id,
+        config: componentConfig,
+        originalBody: answerObject?.originalBody,
       };
     })
     .filter(r => r.answer !== undefined);
